Welcome to our World! Where we serve you cookies to ensure you get the best viewing experience on our site.

Did you know that you can remove censorship board-wide, use our advanced search functions, be notified when new content is posted, join our memberships, set episodes to show in any order you want & more if you are logged into your account?

Register or sign in here: ucp.php?mode=register

16x09 - Client On the Go

Episode transcripts for the TV show, "Project Runway". Aired: December 1, 2004 – present.*
Watch/Buy Amazon


Contestants compete with each other to create the best clothes and are restricted by time, materials and theme.

16x09 - Client On the Go

Post by bunniefuu »

HEIDI:
Previously on Project Runway...

You are using menswear
as inspiration,

but this is a team challenge.

-All right.
-Score. -Yes!

ZAC: I am in love, Margarita,
with your dress.

-It's very now.
-Margarita, you are the winner

of this challenge.
Congratulations.

Claire, Shawn, one of you
will be out, but not yet.

-Oh. -We truly don't know who's
more responsible for what look,

so you will be going
head-to-head

in a one-hour challenge
that starts right now.

Eliminating a designer
on Project Runway

is something that we take
very, very seriously.

-Of course.
-And right now,

we feel like we don't have
enough information

to make that decision.

We need to see what
you can do individually.

You have one hour
to create a new look.

And there's fabric waiting
for you in the workroom.

I shouldn't really have
to say this,

but you cannot help one another.

You're on your own.

Good luck.
See you back here in one hour.

CLAIRE: We are going to have
to find it in ourselves

to not let this challenge
defeat me.

-Or we.

-Or we.
-Yeah.

MAN: Quick, quick, quick.
Here they come.

Those are out. [sighs]

CLAIRE: I select a fabric.
I'm working with it.

I'm making something
happen because

I've been pitted
against my sister.

If I'm going to be voted out

of this competition,
I'm going to do it

out of my own volition.

I don't even...
What-what the hell

am I supposed to do in an hour?

I don't even know.
I don't... I don't...

It's not supposed to be pretty.

[sighing]: God. I just...
I can't even do this.

-[frustrated grunt]
-[mannequin clatters on floor]

SHAWN:
Can I just stop now, please?

I just don't want to do this.

I know.

[sniffles]

Can... Where's Tim?

-Hi, Tim. Um...
-Hi, Shawn.

This is... this is something
that tears at me,

and-and...

[sighs]

I think it's Claire
that needs to stay.

-I already know that it's her.
-TIM: I respect that.

I want to give her the credit
that-that she is due.

I want her to continue
in-in my stead.

-[sobbing]
-I know, babe. Come on.

Come on, babe.

You know I love you so much.

It's very, very,
very hard for me

to accept that she no longer

wants to compete
in this challenge,

because I know
that that's not true.

TIM: Why don't we go down
to see the judges?

-Yes, let's. Thank you.
-TIM: Okay.

TIM: I don't even know
where to stand.

I-I've never done this before.

I have, uh, brought...

Sorry. [sniffles]

Aw. Tim.

I brought Shawn and Claire

because Shawn
has made a decision.

I have.

I stood at that dress form
for 15 minutes,

and nothing came to me,
and-and Claire

was halfway through something.
That says Claire

is here for a reason,
and she needs to continue,

and-and I need to concede.

Claire may have been
carrying me,

and Claire may have been
influencing some of my design.

HEIDI:
Shawn, you have made

some incredible pieces,

if I just think about
last week, for example.

-Thank you. That's very kind.
-You know, so maybe you

cannot deal on this time crunch.

That is my... my Achilles heel.

Are you okay with that, Claire?

It's a very hard place to be.

-Aw. I'm sorry.
-SHAWN: We knew what we

were getting into.
This is...

this is not something that

we knew would be easy.

HEIDI: And, Claire,
for you to stay here,

that shows me
that you have fight.

Thank you, all.
Thank you so much.

HEIDI:
I wish you all the best.

-Thank you so much.
-Auf Wiedersehen.

Oh, babe, it's okay.

Oh, I love you, babe.

I have faith
that she will succeed.

Because...
because she can do this.

She can do this 100%.

♪ ♪

[Claire sighs]

What a [bleep] day.

Yeah.

I'm gonna miss her.

This is gonna be rough.

But on a positive note,

you made a beautiful dress.

-Thank you so much.
-It was beautiful.

MARGARITA: All right, girl,
give me a hug.

I know.

♪ ♪

Hey.

CLAIRE:
It's really hard

to not have Shawn here
for this next challenge,

but I really want to

prove to myself
that I deserve to be here.

TIM:
Come on in, Teresa.

-Hi there.
-Hello! -Hi.

TIM:
Good morning, designers.

Please join me in giving
a hearty welcome

to Teresa Bossong,
brand building leader for Dixie.

-Hi, Teresa. -Hi.
-TERESA: Thank you.

Hi, everyone.
I'm so excited to be here.

At Dixie, we understand
that fashion trends

influence design in every aspect
of people's lives.

Even down to the coffee cups
they grab

when they're setting out
to take on each day.

Dixie believes there's nothing

that matters more
than friends and family.

So, for your next challenge,

you will be dressing
women on the go.

-Ooh. -Okay. Okay.
-And these women on the go

are near and dear to us here
on Project Runway,

because they are the friends
and family of our crew members.

-Oh!
-What?

-Have a look.
-I'm Sara.

I'm an executive producer
on Project Runway,

and I am nominating
my friend Cecilia.

-She's a Project Runway
superfan. -Hi.

She's a busy working mom,

and she deserves
something special.

-Cecilia, you are with Claire.
-Hi there.

CLAIRE:
Cecilia, the friend

of the executive producer

of Project Runway.

My stress level just went up
like a hundred points.

Hey, designers.
I'm Gus Dominguez,

lighting director on the show.
I'm gonna be nominating

-my friend Analyssa.
-Hi.

Do me a favor--
take care of her.

I'm watching you guys.

-[laughter]
-TIM: Analyssa,

-you are with Brandon.
-Hi. -Hi.

Hi, designers. I'm nominating
my mom, Sabrina Hocking.

She was diagnosed with
breast cancer three years ago,

and she's finally starting to
get her energy and spirit back,

so I need a new look for her
to bring back her confidence.

-Hello.
-How are you?

SAPNA SHAH:
I want to nominate my mom.

She wants a look
for an upcoming wedding.

-Hi.
-Nice to meet you. Hi.

KRISTEN ADAMS: I'd like
to nominate my mom, Michele,

because it's my mom's first time
being a grandmother,

and she doesn't want
to start dressing

like a traditional grandmother.

Nice to meet you.

CLIVE SALMON: I'm nominating
my friend Gina Dunlop.

So bring it. That's all I'm
gonna say to y'all-- bring it.

-Hi. Come on in. Nice to
meet you. -Nice to meet you.

CHANDLER DEWITT:
My mom, she's the epitome

-of a woman on the go.
-Hi.

And is in desperate need
of a day-to-night look.

-You look just like
your daughter. -[laughter]

Hi. I'm Oscar Cordova.

I nominate my wife,
Cynthia Cordova.

Yay! Your jumper's so cute.

Hi. Nice to meet you.

I nominate my wife.

Designers, hook her up.

-I want her to feel and know
that she's beautiful. -Hi.

Come on, gorgeous.
I'm so excited.

TIM: Now that we have our
designer/client pairings,

there is one more element
to this challenge.

You will also be creating
a custom print

that is to be featured
within your look.

-[designers gasping, murmuring]
-TERESA: And...

we will take the winning
designer's look

and their custom print,
and we'll use it

to inspire a special
Dixie to-go cup

which will be available
for purchase

-at retailers and online.
-Yeah!

[applause]

Not only that.
The winner will receive $25,000,

-courtesy of Dixie.
-Whoa.

-Whoa.
-Did I hear that right?

This is life-changing.

TIM: Teresa, we're so grateful
to you and to Dixie.

-Thank you so very much.
-Oh, thank you for having us.

Good luck, everyone,
and I can't wait

-to see your designs.
-DESIGNERS: Thank you.

TIM:
Thanks, Teresa.

All right, now,
down to some business.

You have two days
for this challenge.

-[designers murmuring]
-TIM: You will have 30 minutes

to meet with your new client,

and then an additional


to finalize your print.

Your print-design fabric
will be

delivered tomorrow morning.

After your session
with your clients,

we're going to Mood

-for additional materials.
-Sure.

I'll be back.

MICHAEL:
Oh, my God. Oh, my God.

I'm so excited.

GINA:
I kind of want some spunk

-kind of just to match my
personality. -Okay. Okay. Okay.

[laughing]

MICHAEL: As far as a print,
do you like abstract?

-I'm Native American,
so one of the things... -Cool.

-...I like is the Native
American prints. -Yeah.

It's funny that it's a pattern,
because I was gonna tell you,

"I don't wear any patterns,"

-but now I'm like, "Oh, Lord."
-Okay.

-So, how do you feel about
wearing, like, a skirt? -Yeah.

-Or, like... pencil skirt?
-I could do... Yeah.

I want a dress. Long sleeves.

The fact that you want long
sleeves-- awesome. [laughs]

-Okay. Got it.
-So I do have a longer waist.

I... you know, I'm
a little more busty and hip...

-You got cute curves.
-[laughs]

-Now, talk to me about colors.
-I like to go out.

I like to have fun,
but when I travel,

I just pack all black.

Okay. Well, that's smart
for traveling.

Do you like florals?

I kind of like, um...
I like geometrics.

MARGARITA:
I'm like...

"Okay, great."

KENTARO: You want to have,
like, long dress

because, for a wedding,
you don't want

-to do short, right?
-Right. Right.

My favorite color's purple,
but I would never wear purple.

-Oh, never? Why?
-I don't know.

I feel like colors like purple,
green really, like, just

-bring out your energy
and your confidence. -Okay.

'Cause you need some color
to just make you stand out.

-Yeah.
-And make you beautiful.

TIM:
All right, designers.

Say good-bye to your clients.

And, after your clients leave,

you'll have 20 minutes
to design your print.

All righty. Bye.

-Bye. -Bye.
-Bye.

I need more red.

-Hello.
-Hi. Kenya.

-Nice to meet you, Kenya.
-Nice to meet you.

KENYA: How many people
can say that their print

is on a Dixie cup?

AYANA:
My print design is essentially

the word "Dixie" in Arabic.

That's not bad.

I-I want something that's...

that's kind of more graphic.

CLAIRE: My idea is to create
a very large

zigzag pattern
out of a brushstroke.

It's an overall print
that, I think,

is more in keeping with what

Cecilia favors
from her clothing.

I think the main thing I do want
to do is the shapes first.

KENTARO:
I'm going to have a...

probably, like,
a one-inch stripe.

Just run them like...
da-da-da-da-da.

-Is that big enough?
-That's perfect. Yeah.

I want to stretch it out
so it can look

more like tie-dye a little bit.

I bet we could smudge it
as well.

I want it to repeat four times,
but I don't want it to do that.

But I only have two minutes,

so we're just gonna roll
with it.

-Thanks. Thank you.
-[horns honking]

TIM: All right, designers,
you have 30 minutes to shop.

♪ ♪

I'll do three and a half.

-Three and a half?
-Yeah.

-14. Yeah.
-14?

Do you have any modal
in these colors?

Designers, time is up.

Thank you, Mood.

It's gonna tie like this?

MICHAEL: It's supposed to look
like a Native American blanket.

-Oh, cool.
-MICHAEL: I want to make Halona

a jumpsuit with her traditional
Native American roots.

So I want to have
a lot of draping

and a lot of folding over
to mimic

the blanket style around her.

KENTARO:
Oh, my God.

-[chuckles]
-[slap]

I'm trying to figure out
a top for her.

BRANDON: Shawn is gone.
Claire doesn't really have

her person to kind of

run to and, uh,
bounce ideas off of,

and so she seems just lost.

MARGARITA: Claire's sitting
in front of me,

and I can't help but notice

that she's draping a piece
that looks damn near exact

what I made for JCPenney
last week.

I've known that the twins
knock off other designs,

and I was complacent with it,
but now she is copying me.

It is just blowing my mind.

Like, I'm about
to cry right now.

This is so frustrating.

I might just explode.

HEIDI:
Coming up on Project Runway...

-Ooh.
-Super cool.

-Thank you.
-That's a hit.

It's sophisticated.

Well, it just looks
like a slip dress.

Where is the print?

♪ ♪

-I can't wait to see my fabric.
-Oh, I like it a lot.

-Ooh.
-Super cool.

-Can I just use as a scarf?
-[laughter]

My print kicks a*s.

It came out kind of light,
but...

BATANI:
My printed fabric is

spaced out further
than I wanted it to be,

but I decided already that I'm
just going to cut it out

and make, you know,
a new design with it.

Oh, man.

My print's awful.
I mean, it looks tribal.

The color is like a cheesy
pink fuchsia, like Barbie,

and to top it off, I just kept
thinking in my head,

I can't believe Claire
is actually

making what I did
for the last challenge.

It looks like it has to go
with kimono sleeve, right?

BRANDON:
Yeah.

-Hi.
-Hey.

-Hi again.
-Yes.

-And it'll have a big old cuff.
-These are amazing.

-Do you like this little jacket?
-I do.

So, I want it to be reversible.

-Hi, honey.
-It's beautiful!

It is gorgeous.

-Thank you.
-Oh, no. Thank you.

One of the things for me was
I didn't want the matronly look,

but I didn't want a young girl.

She truly gets me.

I love the print.

I've adopted her, and she'll be

coming for Thanksgiving
with us. [laughs]

[indistinct chatter]

What a lively room.

As you know,
this is our critique,

but for our clients, I want you

to think of this
as a coaching session.

-We can do that. You can do
that. -You are helping coach

your designer to $25,000.

-Oh, my gosh. -Yeah.
-TIM: All right?

-Let's go.
-Awesome.

-Kentaro, Kekina.
-Hi.

So, how has
your collaboration been?

-It's been good.
-Good.

She wanted to make a dress
for her friend's wedding,

so I wanted to make
something flowy.

And you have. But I wouldn't
know that this is your design.

Is there enough of you in this?

What do you mean?

Well, it just looks
like a slip dress.

It's not what I would call
an innovation.

What do you think
of the print, though?

-Do you like it?
-Ooh.

-I like the print.
It came out nice. -Yeah.

I'm butting in.
I like the print, too.

How did you come up
with a garment design?

Well, she told me that she likes
wrap-style dresses,

so I'm giving her the option

of either having a skirt--
like a dress--

or like a jumpsuit that wraps.

I look at the top,
I know it's you.

-It has your signature.
-Right.

I look at the skirt,
and Analyssa could have

-bought it from
any number of people. -Yeah.

AMY:
So I'm doing like a jacket.

Black blouse, and then the pants
also in the print.

TIM:
Given how great the shirt is,

what if it's a shirt
and a pair of pants?

-She's in love with the shirt.
-I'm in love with the shirt.

-Like, for real.
-Then let's show it off.

-Yeah. -Okay. -The main
thing we're doing is...

a dress, and then we're still
deciding on pants.

I think the pants beg
the question, "Why?"

We want some skin.
Look at her legs. Fab.

I'm just kidding. [chuckles]

The tone of this
is definitely more yellow

than the blue I had anticipated.

-So I was quick on my feet
to go dye it. -TIM: Oh.

-STACEY: Isn't that pretty?
-Actually, that's a hit.

-Right? So much better.
-Right. -Yeah, love it.

And then I have this jacket
that she can throw on

-over this dress.
-I love this color gray.

-I do, too. It's sophisticated.
-She does. She's...

-Yeah. Yeah.
-Oh, good. That's a good word.

Sabrina is a cancer survivor,

and she wants more color
in her life.

And so this is
what I've been working on.

This is the print
I came up with.

Where is the print?

I'm going to put it here,

here and some in the back.

My initial response when I hear
that Sabrina wants color:

Where is it?

It's just... a gray shroud.

SABRINA: This dress is something
that I would wear at home.

It's not something that I want

to walk down the runway.

It doesn't have any oomph.

What do you think
about this color?

SABRINA:
Oh, I haven't seen this yet.

Yeah, I forgot to show you.

TIM:
Well, you have some color.

What else are you hiding?

Nothing else. Nothing else.
[laughs]

Kenya and Michele, I feel like
I'm interrupting a love fest.

You are. You are.

[laughing]

So, this is her top.

But I'm going to cut it,
'cause I want the peplum piece

to be, like, right at
the small of her waist.

TIM:
It just feels like

an add-on.

CLAIRE: It's going to have
a peplum all the way around

-and have this open piece
right here. -Okay.

-My comment would be...
-Mm-hmm.

MARGARITA: I want to hear
what he's gonna say to Claire

because she's right
in front of me.

It's the elephant in the room.

-TIM: This top...
-CLAIRE: Mm-hmm.

I've seen a similar version
of this before.

-Okay.
-From you.

And I just don't want the judges
to call this out and say,

-"Claire, we've seen this
before." -"We've seen this."

-Sure.
-MARGARITA: Really, Tim?

Did you forget

that it was me who did it?

Please say good-bye
to your clients.

You will see them
in the morning.

Kenya, you can let go
of Michele.

-She'll be back.
-[laughing]: Okay.

-They're making me leave.
-Okay.

Bye.

All right.

You have until 10:30 tonight.

-Yes! -Oh!
-TIM: Work hard.

-I know you will. $25,000
is at stake. -[whooping]

Of course you're going
to work hard.

-All right.
-All right?

-Bye, everybody.
-DESIGNERS: Bye.

-Thank you very much.
-Thank you.

Margarita, I have a question
for you if you have...

if you can look up for two
seconds when you have a second.

I actually think people
in the workroom

are interacting with me

a little less than they...

than they used to
when Shawn was here.

AYANA:
Everyone's kind of just like

whispering around.

I'm sure Claire can feel it,

but no one is saying anything

to her directly,
which I think is an issue.

Is it something you can take off
if it doesn't work?

-Exactly.
-I can't say anything.

I can't say anything,
'cause I'm gonna explode,

and I don't want her
to feel attacked,

but it's really [bleep]
with my focus.

Why do I keep pinning this
the wrong way? Damn it.

She hides it pretty well.

No.

I feel very strongly

about fairness
in the competition,

and the fact that Claire
isn't playing

the game right
really bothers me.

♪ ♪

AMY:
That's a cute top, Claire.

Thank you.

I'm actually pleased with it.

-For once.
-Good place to be.

CLAIRE:
I really agree with

Tim's advice and...

changed the top.

I'm taking the

keyhole accent and putting it

in the front and the back,
as well as on the sleeves.

MARGARITA: Oh, my God! I, like,
don't have enough gray fabric.

So I'm like, "Well,
how am I gonna fix this?"

I have to, like,
use a hot-pink fuchsia.

Like, Jesus, please help me.

All right, everybody,
I'm sleepy.

-DESIGNERS: No!
-Time to go.

MARGARITA:
I'm just feeling so defeated.

HEIDI:
Coming up on Project Runway...

TIM:
There's a lot at stake.

I need that $25,000 in my life.

-Like, I need it right now.
-[bleep]

I'm so embarrassed.

[designers murmuring]

KENYA: Winning this challenge
is everything.

The struggle
as an independent designer

is really real.

I've been evicted two times.

My credit sucks.

So $25,000

in my life is life-changing.

CLAIRE: I'm excited
about this challenge.

I feel like everyone

is struggling equally, so...

I don't feel like
I'm behind at least

in any capacity.

I'm feeling pretty good.

Good morning, everyone.

DESIGNERS:
Good morning, Tim.

Anyone in the Brother Sewing
and Embroidery Studio?

Please come in
just for a minute.

You have an hour
to send your clients

to the Avon Beauty Lab

and to our hair studio.

And then you'll have 15 minutes
to prep them for the runway.

Use the JCPenney accessory wall
carefully.

Your clients are coming in
momentarily.

-Have fun with this.
-Thank you.

All right? And remember,
there's a lot at stake.

Oh, you had to remind us.

-TIM: Okay? Thank you.
-Bye, Tim.

BATANI: I'm focused.
This is my challenge.

I have to win. Like, I need
that $25,000 in my life.

Like, I need it right now.

-Hey!
-Hello.

I need you to try this on
immediately.

Oh, my God, they fit perfectly.

Awesome!

Love that.

-Nice, huh?
-Yeah.

This is perfect.

That's my style.
I love it.

Thank you.

So, the gray ended up
not working

-'cause I didn't have
enough of it. -Oh, no.

And I was like, "We'll just
have to go with the fuchsia."

I'm actually very pleased about

-the length and everything.
-Yay!

MICHAEL:
So, what do you think?

I kind of switched it up
a little bit.

-I like that.
-Yeah?

-Yeah. Makes it different.
-Mm-hmm.

♪ ♪

-KENYA: Hector.
-[Hector chuckling]

I would love for her to have
a nice, glossy, pink lip.

-HECTOR: We use a little bit
of the blush. -KENYA: Yes.

-[camera shutter clicks]
-KENYA: Make her look rosy.

What I'm looking for is

a light, smoky eye.

-HECTOR: Really sexy.
-CLAIRE: Yeah.

HECTOR: For the inside
of the eye, I'm going

-to use eye shadow.
-Oh, that's pretty.

-[camera shutter clicks]
-CLAIRE: Va-va-voom.

♪ ♪

-Milady.
-Thank you.

MICHELE:
I feel like Cinderella.

I love the look

that Kenya designed for me.

It's sexy.

It's classy.
It makes me feel good.

There we go.

I really like the length
of this.

-Like to think it helps a lot.
-Yeah. It does.

STACEY:
I love Margarita.

She is extremely creative.

She overcame some
pretty serious obstacles.

But she is a risk-taker,
and she will try new things.

You're the sweetest.

Turn to the side for me.

The front detail,

-you'll have your slit.
-Yeah.

KENYA:
I saw some skin.

I saw legs. I'm like,

this is not the Ayana
that I know.

I think the opening's
kind of cute.

Designers, in ten minutes,
you and your clients and I

are going down to the runway.
Ten minutes.

♪ ♪

Well, Tim's got color now,
hasn't he?

I love the purple.
I love the color.

It's snug. It's soft.

I feel like it's me.

Cute, cute.

Oh, you look great.

CECILIA:
I love this look.

I feel so confident in it.

Fits perfectly.

It is truly a work of art.

-Okay.
-TIM: Designers and clients,

we're headed down to the runway.

Ayana? Margarita?

MARGARITA:
I'm not feeling good

about this at all.

You know when you're proud
of something

and when you're not,
and I'm just feeling like

I let my emotions
get the best of me.

I'm so embarrassed.

-Hello.
-Hi, Heidi. -Hello.

Welcome to the runway.
As you know, in fashion,

one day you're in,
and the next day you're out.

There are nine of you here,
and after tonight

there will be eight.

-How are you all feeling?
-[light laughter]

Margarita, what about you?
How do you feel?

-[Heidi gasps]
-ZAC: Uh-oh.

I feel defeated.

Thank God I have that immunity.

-Thank God.
-HEIDI: I was just about

to say,
the tears don't have to come,

because you have immunity,
and you cannot

be eliminated today.

Phew.

In fact, you have
the last immunity.

-That's it.
-[quiet groan]

There will be no more
going forward.

For this challenge, you designed
looks for women on the go,

and these women are friends
and family of our crew members.

This was also a print challenge.

The winner of today's challenge
will have

their custom print used
as an inspiration

for a special Dixie to-go cup.

And the winner will receive
$25,000, courtesy of Dixie.

-Thank you, Dixie.
-Yes, thank you, Dixie.

All right, let's say hello
to our judges.

First, we have
creative director

for Brooks Brothers Women
and fashion designer,

-Zac Posen.
-Hi, Zac. -Hi, designers.

Creative director
for Marie Claire magazine,

-Nina Garcia.
-Hello, designers.

-Hi, Nina.
-And our guest judges for today:

author of her new book,
Believe Me,

and host of Lifetime's
upcoming series,

Making a Model
with Yolanda Hadid.

-Hi, designers.
-Hi, Yolanda.

HEIDI: We also have model
Sophia Stallone.

-Hi, everyone.
-Hi, Sophia. -Hi.

And we have Tim Gunn here
for the runway show.

As you know, he is your mentor

and will not be
judging your looks.

We also have
an anonymous runway show.

That means the judges
will not know

which designer
created which look.

Let's start the show.

♪ ♪

[designers exclaiming]

AMY:
She looks great.

I feel that she's presenting
the garment well.

I feel the garment looks good.

I'm happy with it.

BRANDON: She's k*lling it.
She looks amazing.

She embodies the look
completely.

And I just feel so good
that I was able

to pump out this look for her,
and I can tell

it's really resonating
with her,

and she's never worn
nothing like it.

♪ ♪

Those tones are really good.

BATANI: Sabrina's walking
down the runway,

just really jazzy and sassy.

I like the colors, I like
the dress and everything,

but my look has less print
than everybody else's,

so I just hope it stands out
and catches their eyes.

MARGARITA:
Stacey looks super happy.

She's a natural walker.
Her legs look amazing.

The colors actually complement
her skin tone really well.

It's not my favorite,
but it still pops.

♪ ♪

CLAIRE: I think that my look
not only has a very bold

and dynamic print,
but she could go

almost anywhere in that look

and look chic and fashionable.

AYANA:
Cynthia is, like, glowing.

She looks very confident,
and she looks really happy.

I really love
what we created together,

so I just hope that the judges
see that energy

and they love it.

♪ ♪

MICHAEL: I'm happy with how
the separates look on Halona.

The pants look really cool
and interesting,

and the top is something
she would actually really wear.

I tried to give Halona
something very fashionable

and forward-thinking.

[laughter]

KENYA: Michele hits the corner
of the runway,

and I immediately start to cry.

She looks great.
She feels great.

She just feels so happy.

We have this bond now.
That's like my mom now.

So I was just so happy
to see her.

♪ ♪

-Okay...
-Wow.

KENTARO:
My dress is airy, flowy,

has a lot of
beautiful movement,

so I'm so happy.

Designers, this was
a real fun challenge today.

If I call your name,
please step forward.

Batani. Michael.

Kentaro. Kenya.

Margarita.

Claire. Please step forward.

If I've not called your name,
congratulations.

Your scores have qualified you
to move on to the next round.

You can leave the runway.
Thank you.

The six of you have the highest
and the lowest scores.

One of you
will be named the winner,

and one of you will be out.

HEIDI:
Welcome, models.

I have to say,
all of you did a fantastic,

fantastic job today.

MODELS:
Thank you.

Batani, tell us about
your look, your print--

I can't figure out where it is--
and what your client wanted.

BATANI:
My model is Sabrina.

She's a cancer survivor.

She said she was feeling
a lack of energy,

and she didn't have much color
in her wardrobe,

and her favorite color
was purple.

And she likes tie-dye, so I did
a sort of tie-dye print.

-Batani, you're the queen
of prints. And, like... -I am.

I'm looking at this look going
down the runway, I'm like,

-"Where's the print?"
-Where is the print?

BATANI: When it came out
on the fabric,

it was kind of different

than I wanted,
so I just scaled it down.

-Sabrina, how do you like
your look? -I have to tell you,

I feel pretty sexy
and hot in this.

-[laughter] -Well,
that's the most important.

SABRINA: And that's what
I was looking for--

something that makes me feel

beautiful and starting
another chapter in my life.

SOPHIA: The purple
looks beautiful on you,

but asymmetrical hemline,
asymmetrical belt.

Then the vest--
just, nothing is balanced.

This was a print challenge.

That's what it was.

This was your challenge.

-Big missed opportunity.
-HEIDI: Michael.

She mentioned that she does have
Native American roots,

so we both agreed
on a color palette

of orange and blues.

As far as design,
I created kind of a blanket--

Native American wrap style.

Halona,
how do you like your look?

It's beautiful.
I love my blouse the most

-'cause of the print.
-ZAC: I think your model

did a terrific job.

I am pretty disappointed
with this from you.

NINA: You had a very
ambitious design, but...

there's too much going on,
and you didn't

take into consideration
her proportions.

These pants need somebody
quite tall.

I got immediately what you were
trying to do with the print,

but I didn't like
the openings on the sleeve.

It's just a lot.

Kenya, tell us about your look,

your client
and what your client wanted.

Michele is 60.
She's a grandmother

who doesn't want to look
like a grandmother.

She wants something nice,
sophisticated.

And the top was inspired
by Dixie.

I think that would be really,
really cute on a cup.

And I think
that I made her happy.

Well, she made me happy.

Yeah, she just made me feel
really good with her design.

Kenya, you certainly know
how to whip up a blouse.

You keep giving us beautiful,
beautiful tops,

and this one is no exception.

This kind of
peplum empire thing--

-I've seen it a lot from you.
-Okay.

I think to do a peplum
right under the chest...

[clicks tongue]
does not look good.

ZAC: It makes her
very short-waisted.

HEIDI:
Also, the skirt,

it's too tight.

I was not a fan today, Kenya.

But she feels good in it,

so who cares
what the judges think?

-But you should.
-[light laughter]

Thank you, Kenya.
Kentaro.

She asked me to make a dress
for her Indian friend's wedding.

She was inspiring me
about Indian culture,

how they use, like,
different bright colors,

so this was first time
I went for color color.

Ever, or in the competition?

No, ever.
I feel like I became

a new designer a little bit.

This is sublime.

The movement.
Color is your friend.

These colors just sang
down that runway.

The print is effective.

The finishing.

The whole thing.

-I'm blown away by this.
-Thank you so much.



In every turn she makes,
this dress is stunning.

It just really knocked me
off my feet.

I am so proud of you.

HEIDI:
Claire.

This is my stunning model,
Cecilia.

And one of the first things
she tells me

is that she really doesn't
favor prints.

So I had a little
mini heart attack.

CECILIA:
I was so nervous

when I heard that it
was a print challenge,

and she created something
that I would want in my closet.

-I love this.
-Looking at Cecilia today,

I think she looks perfect
head-to-toe.

-Thank you so much. -To me,
this is a woman on the go.

You gave her a great pair
of pants with a great print.

It looks very chic
and very modern.

ZAC:
When it came down the runway,

immediately I thought,
"This was

-the effective print." -I would
want to have that Dixie cup.

-[laughter]
-So... Yeah. -That's good.

NINA:
That really worked.

NINA: I think,
in terms of the design,

am I blown away?
Have I never seen this before?

No, I have seen
a version of this.

But it's suitable
for your model.

She feels very comfortable,
and I think many women would.

Sure.

Margarita, tell us about
your look, your print,

and what your client wanted.

MARGARITA:
Stacey travels a lot.

She's a woman on the go.

She doesn't really wear
a lot of color,

but she wanted
something that would

brighten up her wardrobe.

I did not anticipate

that the print color and scale
would come

in the way that it did,
and I ran out of fabric.

It was just a snowball effect.

Stacey, how do you feel
in your look?

I feel like she
is a long-distance runner.

-She rallied. She had great
vision. -Nice.

She was just fabulous.

What most confuses me--
the dress looks like

she's a preppy lady
going to Martha's Vineyard,

and then the top
looks like she's going

to a c*ck party in the city.

They have no connection
whatsoever.

-I got lost.
-It is... Yes.

YOLANDA:
I do like pink with gray, but I

would have rather seen the dress

with a pair of flip-flops
and a beach bag.

-What happened?
-[sighs]

I put so much pressure
on myself,

and I got distracted
from everything else

that was going on
in the workroom

and just lost my focus, so...

Margarita, what was
so distracting in the workroom?

-I wasn't raised to throw people
under the bus, so... -[gasps]

I'm just gonna...

Hmm.

Thank you, Stacey.

Thank you, Margarita.

Thank you, guys.

HEIDI: Okay, we've heard
what you had to say.

We're going to take
a closer look at your designs,

have a little chat,
and then I'll call you back

onto the runway.
Thank you.

HEIDI: The winner
of Project Runway will receive

the opportunity to collaborate
with JCPenney

on a limited edition
capsule collection

as part
of the Project Runway line sold

at select JCPenney stores
and online at JCP.com;

a selection of Brother sewing
and embroidery machines,

with a retail value of $40,000;

makeup and beauty products
for a year, courtesy of Avon;

the new 2018 Lexus NX,
coming this fall

with advanced innovation
and safety system standard;

from the Pilot FriXion
Erasable Pen,

the official pen
of Project Runway,

a lifetime supply of pens;

an all-expense-paid luxury trip
to Japan,

including a five-star stay
near Japan's fashion center;

$100,000 to launch their line;

and the winning designer
and model will receive

a fashion spread
in Marie Claire magazine.

-Hello, ladies.
-Hi. -Hi.

-TIM: So, should we begin with
Michele wearing Kenya? -Yes.

ZAC:
I mean, the stitch,

the detailing there--
really amazing.

The cuffs, the pleats--
the back is all pleated.

-There's no doubt she put so
much work into this. -Oh. -Yeah.

I mean, I just don't think
it is flattering on you.

Because you're quite busty,
and then you have the peplum,

like, right under the bust.

-I like it.
-That's so much better.

HEIDI: Already,
she looks better like that.

If you had the simpler top and
tucked it in or something...

NINA: I like the peplum.
I think the problem here

is that you have the peplum,
and then you have a peplum.

Yeah, that was my issue.

♪ ♪

TIM: And we have
Cecilia wearing Claire.

-ZAC: I want to see this
close up. -So great.

This outfit looks perfect
on you.

-YOLANDA: I like that top.
-Yeah.

I mean, I love
the little details.

And the print is really
original. I love it.

HEIDI: To me, this looks
like a woman on the go.

-Kekina is wearing Kentaro.
-ZAC: Wow.

-Beautiful.
-For me, I just see fabric.

When she takes this off,
now I feel like I see

some shoulders,
I see some of her body.

I like that it wasn't a
full belt; it was a half belt.

And it does fit
her waist well there.

-So beautiful. -This is
a nice touch here in the back.

I like the color combination
a lot.

-I love the color combination.
-It's beautiful.

ZAC: Did they all sew in
the Dixie label?

-No. -ZAC: Pretty cool.
-Yeah, it's cute.

♪ ♪

TIM:
Halona is wearing Michael.

You know, I think he was trying
something different here.

HEIDI: I just think
it's too over-designed.

Already, the print is so strong,

and then you see the skin here,

and then there is another
embellishment here.

-He embellished it here.
-Yeah, I agree.

NINA: I would have loved
to see this same treatment

but in just one print.

-So it blends in.
-With-- yes.

This is just a lot.

♪ ♪

And Sabrina is wearing Batani.

-Well, Batani forgot
her prints today. -I know.

TIM: She's all about color
and prints and...

-Vibrancy. Graphic.
-Absolutely.

What happened? Why...?

Well, the repeat

would have been here
and down here.

I mean, there was this huge gulf

-between them.
-Right. Got it.

-And it didn't work
as a textile. -Right.

-ZAC: It's just a shame.
-HEIDI: It's really like

-there's not a whole lot here.
-No.

It is the most simple dress.
When you take this off,

-there's, like, nothing to it.
-Uh-uh. -Yeah.

-Stacey is wearing Margarita.
-ZAC: Poor Margarita.

And she has immunity, and she
was in tears on the runway.

It must have been
a real struggle for her.

-I felt so bad. -STACEY: Well,
yeah, 'cause this was gonna be

-this with gray, but there was
not enough gray fabric. -Got it.

So then the bolero jacket
would have more blended...

-STACEY: The bolero jacket...
-ZAC: Would've blended maybe.

-Yeah. -She really had
a "make it work" moment.

-TIM: She did.
-She did.

♪ ♪

Okay, so we've made
our decision?

Have we?

Let's bring them back out.

One of you will win $25,000.

And you will have your print

on a Dixie cup.

And one of you will be out.

Claire, congratulations.

You are the winner
of this challenge.

♪ ♪

[whispering]:
Wow.

-TIM: Who's leaving?
-[indistinct chatter]

Michael, why are you
running off the stage?

I came to play fair, and...

there's no fairness
in this game.

Okay.

What happened?
What's happening, you guys?

What happened?

[laughs] Like, I want to know
what's going on backstage.

Michael, what's wrong?

-What's wrong?
-I apologize for making a scene.

-No, no, no. What's wrong?
-I sincerely apologize for that.

What's wrong?
I honestly don't know.

All right, so I do believe
in fairness,

and I believe
that this win lacks that.

Well, you're entitled
to your opinion.

It has nothing to do
with the design.

It has to do with what
is actually going on

behind the scenes.

What is happening?

None of us want
to point fingers.

At who?

HEIDI:
Next time on Project Runway...

-That has never happened before.
-That's concerning.

MICHAEL:
We understand what she is doing,

and she knows
what she is doing as well.

Well, we will look into this.

Well, this is an interesting
turn of events.

He's not happy
with you winning this?

I'm gonna go find Michael.

-Mmm...
-HEIDI: Somebody tell us

what is going on.

[door closes]

All right, first things first.

[makes expl*si*n sound]

HEIDI:
Visit myLifetime.com to learn

more about the fashion
you've seen on tonight's show.